Documentation
¶
Index ¶
- type APIError
- type DetectedLanguage
- type GlossaryTerm
- type ImportJob
- type Memory
- type ModernMT
- func Create(apiKey string) *ModernMT
- func CreateWithClientId(apiKey string, apiClient int64) *ModernMT
- func CreateWithIdentity(apiKey string, platform string, platformVersion string) *ModernMT
- func CreateWithIdentityAndClientId(apiKey string, platform string, platformVersion string, apiClient int64) *ModernMT
- func (re *ModernMT) BatchTranslate(webhook string, source string, target string, q string, ...) (bool, error)
- func (re *ModernMT) BatchTranslateAdaptive(webhook string, source string, target string, q string, hints []int64, ...) (bool, error)
- func (re *ModernMT) BatchTranslateAdaptiveWithKeys(webhook string, source string, target string, q string, hints []string, ...) (bool, error)
- func (re *ModernMT) BatchTranslateList(webhook string, source string, target string, q []string, ...) (bool, error)
- func (re *ModernMT) BatchTranslateListAdaptive(webhook string, source string, target string, q []string, hints []int64, ...) (bool, error)
- func (re *ModernMT) BatchTranslateListAdaptiveWithKeys(webhook string, source string, target string, q []string, hints []string, ...) (bool, error)
- func (re *ModernMT) DetectLanguage(q string, format string) (DetectedLanguage, error)
- func (re *ModernMT) DetectLanguages(q []string, format string) ([]DetectedLanguage, error)
- func (re *ModernMT) GetContextVector(source string, target string, text string, hints []int64, limit int) (string, error)
- func (re *ModernMT) GetContextVectorByKeys(source string, target string, text string, hints []string, limit int) (string, error)
- func (re *ModernMT) GetContextVectorFromFile(source string, target string, file *os.File, hints []int64, limit int, ...) (string, error)
- func (re *ModernMT) GetContextVectorFromFileByKeys(source string, target string, file *os.File, hints []string, limit int, ...) (string, error)
- func (re *ModernMT) GetContextVectorFromFilePath(source string, target string, path string, hints []int64, limit int, ...) (string, error)
- func (re *ModernMT) GetContextVectorFromFilePathByKeys(source string, target string, path string, hints []string, limit int, ...) (string, error)
- func (re *ModernMT) GetContextVectors(source string, targets []string, text string, hints []int64, limit int) (map[string]interface{}, error)
- func (re *ModernMT) GetContextVectorsByKeys(source string, targets []string, text string, hints []string, limit int) (map[string]interface{}, error)
- func (re *ModernMT) GetContextVectorsFromFile(source string, targets []string, file *os.File, hints []int64, limit int, ...) (map[string]interface{}, error)
- func (re *ModernMT) GetContextVectorsFromFileByKeys(source string, targets []string, file *os.File, hints []string, limit int, ...) (map[string]interface{}, error)
- func (re *ModernMT) GetContextVectorsFromFilePath(source string, targets []string, path string, hints []int64, limit int, ...) (map[string]interface{}, error)
- func (re *ModernMT) GetContextVectorsFromFilePathByKeys(source string, targets []string, path string, hints []string, limit int, ...) (map[string]interface{}, error)
- func (re *ModernMT) HandleTranslateCallback(body []byte, signature string) (Translation, error)
- func (re *ModernMT) HandleTranslateCallbackWithMetadata(body []byte, signature string, metadata interface{}) (Translation, error)
- func (re *ModernMT) HandleTranslateListCallback(body []byte, signature string) ([]Translation, error)
- func (re *ModernMT) HandleTranslateListCallbackWithMetadata(body []byte, signature string, metadata interface{}) ([]Translation, error)
- func (re *ModernMT) ListSupportedLanguages() ([]string, error)
- func (re *ModernMT) Me() (User, error)
- func (re *ModernMT) Qe(source string, target string, sentence string, translation string) (QualityEstimation, error)
- func (re *ModernMT) QeList(source string, target string, sentences []string, translations []string) ([]QualityEstimation, error)
- func (re *ModernMT) Translate(source string, target string, q string, options *TranslateOptions) (Translation, error)
- func (re *ModernMT) TranslateAdaptive(source string, target string, q string, hints []int64, contextVector string, ...) (Translation, error)
- func (re *ModernMT) TranslateAdaptiveWithKeys(source string, target string, q string, hints []string, contextVector string, ...) (Translation, error)
- func (re *ModernMT) TranslateList(source string, target string, q []string, options *TranslateOptions) ([]Translation, error)
- func (re *ModernMT) TranslateListAdaptive(source string, target string, q []string, hints []int64, contextVector string, ...) ([]Translation, error)
- func (re *ModernMT) TranslateListAdaptiveWithKeys(source string, target string, q []string, hints []string, contextVector string, ...) ([]Translation, error)
- type QualityEstimation
- type TranslateOptions
- type Translation
- type User
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DetectedLanguage ¶ added in v1.0.4
type GlossaryTerm ¶ added in v1.5.0
type ModernMT ¶
type ModernMT struct {
Memories memoryServices
// contains filtered or unexported fields
}
func CreateWithClientId ¶ added in v1.1.0
func CreateWithIdentity ¶
func CreateWithIdentityAndClientId ¶ added in v1.1.0
func (*ModernMT) BatchTranslate ¶ added in v1.2.0
func (*ModernMT) BatchTranslateAdaptive ¶ added in v1.2.0
func (*ModernMT) BatchTranslateAdaptiveWithKeys ¶ added in v1.2.0
func (*ModernMT) BatchTranslateList ¶ added in v1.2.0
func (*ModernMT) BatchTranslateListAdaptive ¶ added in v1.2.0
func (*ModernMT) BatchTranslateListAdaptiveWithKeys ¶ added in v1.2.0
func (*ModernMT) DetectLanguage ¶ added in v1.0.4
func (re *ModernMT) DetectLanguage(q string, format string) (DetectedLanguage, error)
func (*ModernMT) DetectLanguages ¶ added in v1.0.4
func (re *ModernMT) DetectLanguages(q []string, format string) ([]DetectedLanguage, error)
func (*ModernMT) GetContextVector ¶
func (*ModernMT) GetContextVectorByKeys ¶ added in v1.0.3
func (*ModernMT) GetContextVectorFromFile ¶
func (*ModernMT) GetContextVectorFromFileByKeys ¶ added in v1.0.3
func (*ModernMT) GetContextVectorFromFilePath ¶
func (*ModernMT) GetContextVectorFromFilePathByKeys ¶ added in v1.0.3
func (*ModernMT) GetContextVectors ¶
func (*ModernMT) GetContextVectorsByKeys ¶ added in v1.0.3
func (*ModernMT) GetContextVectorsFromFile ¶
func (*ModernMT) GetContextVectorsFromFileByKeys ¶ added in v1.0.3
func (*ModernMT) GetContextVectorsFromFilePath ¶
func (*ModernMT) GetContextVectorsFromFilePathByKeys ¶ added in v1.0.3
func (*ModernMT) HandleTranslateCallback ¶ added in v1.2.0
func (re *ModernMT) HandleTranslateCallback(body []byte, signature string) (Translation, error)
func (*ModernMT) HandleTranslateCallbackWithMetadata ¶ added in v1.2.0
func (re *ModernMT) HandleTranslateCallbackWithMetadata(body []byte, signature string, metadata interface{}) (Translation, error)
func (*ModernMT) HandleTranslateListCallback ¶ added in v1.2.0
func (re *ModernMT) HandleTranslateListCallback(body []byte, signature string) ([]Translation, error)
func (*ModernMT) HandleTranslateListCallbackWithMetadata ¶ added in v1.2.0
func (re *ModernMT) HandleTranslateListCallbackWithMetadata(body []byte, signature string, metadata interface{}) ([]Translation, error)
func (*ModernMT) ListSupportedLanguages ¶
func (*ModernMT) Translate ¶
func (re *ModernMT) Translate(source string, target string, q string, options *TranslateOptions) (Translation, error)
func (*ModernMT) TranslateAdaptive ¶
func (re *ModernMT) TranslateAdaptive(source string, target string, q string, hints []int64, contextVector string, options *TranslateOptions) (Translation, error)
func (*ModernMT) TranslateAdaptiveWithKeys ¶ added in v1.0.3
func (re *ModernMT) TranslateAdaptiveWithKeys(source string, target string, q string, hints []string, contextVector string, options *TranslateOptions) (Translation, error)
func (*ModernMT) TranslateList ¶
func (re *ModernMT) TranslateList(source string, target string, q []string, options *TranslateOptions) ([]Translation, error)
func (*ModernMT) TranslateListAdaptive ¶
func (re *ModernMT) TranslateListAdaptive(source string, target string, q []string, hints []int64, contextVector string, options *TranslateOptions) ([]Translation, error)
func (*ModernMT) TranslateListAdaptiveWithKeys ¶ added in v1.0.3
func (re *ModernMT) TranslateListAdaptiveWithKeys(source string, target string, q []string, hints []string, contextVector string, options *TranslateOptions) ([]Translation, error)
type QualityEstimation ¶ added in v1.3.0
type QualityEstimation struct {
Score float32
}
type TranslateOptions ¶
type Translation ¶
Click to show internal directories.
Click to hide internal directories.